class Device():
    def __init__(self, name, description, primaryIP4Id, primaryIP4Address, serialNumber, locationId, locationName, siteId, siteName, organizationId, organizationName, rackId, rackFace, id, netBoxId, validFrom, validTo, isActive):
        self.name = name
        self.description = description
        self.primaryIP4Id = primaryIP4Id
        self.primaryIP4Address = primaryIP4Address
        self.serialNumber = serialNumber
        self.locationId = locationId
        self.locationName = locationName
        self.siteId = siteId
        self.siteName = siteName
        self.organizationId = organizationId
        self.organizationName = organizationName
        self.rackId = rackId
        self.rackFace = rackFace
        self.validFrom = validFrom
        self.validTo = validTo
        self.isActive = isActive
        self.id = id

        self.netBoxId = netBoxId

    def __str__(self):
        return self.name

    def __repr__(self):
        return self.name



class Location():
    def __init__(self, name, description, roomPin, locations, parentId, id):
        self.name = name
        self.description = description
        self.roomPin = roomPin
        self.parentId = parentId
        self.id = id

        if locations:
            self.locations = []
            for location in locations:
                self.locations.append(Location(**location))
        else:
            self.locations = locations



class District():
    def __init__(self, name, regionId, regionName, isActive, id):
        self.name = name
        self.regionId = regionId
        self.regionName = regionName
        self.isActive = isActive
        self.id = id



class Municipality():
    def __init__(self, name, districtId, districtName, regionId, regionName, isActive, id):
        self.name = name
        self.districtId = districtId
        self.districtName = districtName
        self.regionId = regionId
        self.regionName = regionName
        self.isActive = isActive
        self.id = id



class Address():
    def __init__(self, municipalityId, municipalityName, districtId, districtName, regionId, regionName, houseNumber, referenceNumber, zip, streetName, streetId, text, isActive, id):
        self.municipalityId = municipalityId
        self.municipalityName = municipalityName
        self.districtId = districtId
        self.districtName = districtName
        self.regionId = regionId
        self.regionName = regionName
        self.houseNumber = houseNumber
        self.referenceNumber = referenceNumber
        self.zip = zip
        self.streetName = streetName
        self.streetId = streetId
        self.text = text
        self.isActive = isActive
        self.id = id



class Organization():
    def __init__(self, id, abraCustomerId, address, hasActiveContract, icoNumber, isActual, isCustomer, name, abraCode, xUcastnikId, clientId, updatedAt, updatedBy, isMember, isCanceledMemberPart, masterOrganizationId, masterOrganizationAbraId, masterOrganizationName,  entityId, isVip, vipNote, organizationTypeId, organizationTypeName):
        self.id = id
        self.abraCustomerId = abraCustomerId
        self.addres = address
        self.hasActiveContract = hasActiveContract
        self.icoNumber = icoNumber
        self.isActual = isActual
        self.isCustomer = isCustomer
        self.name = name
        self.abraCode = abraCode
        self.xUcastnikId = xUcastnikId
        self.clientId = clientId
        self.updatedAt = updatedAt
        self.updatedBy = updatedBy
        self.isMember = isMember
        self.isCanceledMemberPart = isCanceledMemberPart
        self.masterOrganizationId = masterOrganizationId
        self.masterOrganizationAbraId = masterOrganizationAbraId
        self.masterOrganizationName = masterOrganizationName
        self.entityId = entityId
        self.isVip = isVip
        self.vipNote = vipNote
        self.organizationTypeId = organizationTypeId
        self.organizationTypeName = organizationTypeName



from komora_syncer.models.komora.location import Location
from komora_syncer.models.komora.address import Address
from komora_syncer.models.komora.site_contact import SiteContact


class Site():
    def __init__(self, name, fullName, description, facility, latitude, longitude, contacts, address, isActive, locations, id, organizationId, organizationName, code, typeId, typeName):
        self.name = str(name or "").strip()
        self.fullName = str(fullName or "").strip()
        self.description = str(description or "").strip()
        self.facility = facility
        self.latitude = latitude
        self.longitude = longitude
        self.code = code
        self.typeId = typeId
        self.typeName = typeName
        self.isActive = isActive
        self.id = id

        self.organizationId = organizationId
        self.organizationName = organizationName

        if address:
            self.address = Address(**address)
        else:
            self.address = address

        if locations:
            self.locations = []
            for location in locations:
                self.locations.append(Location(**location))
        else:
            self.locations = locations

        if contacts:
            self.contacts = []
            for contact in contacts:
                self.contacts.append(SiteContact(**contact))
        else:
            self.contacts = contacts

        self.flatten_locations = flatten_locations(
            self.locations) if self.locations else []


def flatten_locations(nested_locations):
    result = []

    def flat(nested_locations):
        for location in nested_locations:
            result.append(location)
            flat(location.locations)
        return result

    flat(nested_locations)
    return result



from typing import List
from datetime import datetime


class ContactType:
    contact_id: int
    contract_id: int
    contact_type_id: int
    contact_type_name: str
    id: int

    def __init__(self, contact_id: int, contract_id: int, contact_type_id: int, contact_type_name: str, id: int) -> None:
        self.contact_id = contact_id
        self.contract_id = contract_id
        self.contact_type_id = contact_type_id
        self.contact_type_name = contact_type_name
        self.id = id


class Email:
    email_address: str

    def __init__(self, email_address: str) -> None:
        self.email_address = email_address


class Organization:
    organization_name: str
    organization_id: int
    isActive: bool

    def __init__(self, organization_name: str, organization_id: int, isActive: bool) -> None:
        self.organization_name = organization_name
        self.organization_id = organization_id
        self.isActive = isActive


class Tag:
    contact_id: int
    tag_id: int
    tag_name: str
    note: str
    id: int

    def __init__(self, contact_id: int, tag_id: int, tag_name: str, note: str, id: int) -> None:
        self.contact_id = contact_id
        self.tag_id = tag_id
        self.tag_name = tag_name
        self.note = note
        self.id = id


class Contact:
    firstName: str
    surname: str
    title: str
    suffix: str
    contactTypes: List[ContactType]
    phoneNumber: str
    isActive: bool
    address: str
    phoneNumber2: str
    street: str
    city: str
    postCode: str
    validFrom: datetime
    validTo: datetime
    abraContactId: str
    organizations: List[Organization]
    updatedAt: datetime
    updatedBy: str
    fullName: str
    isEditable: bool
    lastContactedNote: str
    lastContactedBy: str
    lastContactedAt: datetime
    emails: List[Email]
    tags: List[Tag]
    id: int

    def __init__(self, firstName: str, surname: str, title: str, suffix: str, contactTypes: List[ContactType], phoneNumber: str, isActive: bool, address: str, phoneNumber2: str, street: str, city: str, postCode: str, validFrom: datetime, validTo: datetime, abraContactId: str, organizations: List[Organization], updatedAt: datetime, updatedBy: str, fullName: str, isEditable: bool, lastContactedNote: str, lastContactedBy: str, lastContactedAt: datetime, emails: List[Email], tags: List[Tag], id: int) -> None:
        self.firstName = firstName
        self.surname = surname
        self.title = title
        self.suffix = suffix
        self.contactTypes = contactTypes
        self.phoneNumber = phoneNumber
        self.isActive = isActive
        self.address = address
        self.phoneNumber2 = phoneNumber2
        self.street = street
        self.city = city
        self.postCode = postCode
        self.validFrom = validFrom
        self.validTo = validTo
        self.abraContactId = abraContactId
        self.organizations = organizations
        self.updatedAt = updatedAt
        self.updatedBy = updatedBy
        self.fullName = fullName
        self.isEditable = isEditable
        self.lastContactedNote = lastContactedNote
        self.lastContactedBy = lastContactedBy
        self.lastContactedAt = lastContactedAt
        self.emails = emails
        self.tags = tags
        self.id = id


"""
 "data": [
    {
      "firstName": "string",
      "surname": "string",
      "title": "string",
      "suffix": "string",
      "contactTypes": [
        {
          "contactId": 0,
          "contractId": 0,
          "contactTypeId": 0,
          "contactTypeName": "string",
          "id": 0
        }
      ],
      "phoneNumber": "string",
      "isActive": true,
      "address": "string",
      "phoneNumber2": "string",
      "street": "string",
      "city": "string",
      "postCode": "string",
      "validFrom": "2021-11-08T08:49:44.972Z",
      "validTo": "2021-11-08T08:49:44.972Z",
      "abraContactId": "string",
      "organizations": [
        {
          "organizationName": "string",
          "organizationId": 0,
          "isActive": true
        }
      ],
      "updatedAt": "2021-11-08T08:49:44.972Z",
      "updatedBy": "string",
      "fullName": "string",
      "isEditable": true,
      "lastContactedNote": "string",
      "lastContactedBy": "string",
      "lastContactedAt": "2021-11-08T08:49:44.972Z",
      "emails": [
        {
          "emailAddress": "string"
        }
      ],
      "tags": [
        {
          "contactId": 0,
          "tagId": 0,
          "tagName": "string",
          "note": "string",
          "id": 0
        }
      ],
      "id": 0
    }
  ]
"""
